pydmt.core package — pydmt Documentation

# pydmt.core package

## Submodules

## pydmt.core.cache module

cache.py

class pydmt.core.cache.Cache

  Bases: `object`

  get_list_filename(signature: str)
  get_object_filename(signature: str)
  static iterate_objects(file_name: str) → Iterable[tuple[str, str]]
  list_sig_ok(signature: str)

    return if a signature is indeed a list and all objects are intact :param signature: :return:

  save_list_by_signature(signature: str, d: dict)
  save_object_by_signature(signature: str, file_name: str)

## pydmt.core.graph module

graph.py

class pydmt.core.graph.Graph

  Bases: `object`

## pydmt.core.pydmt module

pydmt.py

class pydmt.core.pydmt.BuildProcessStats

  Bases: `object`

  add_builder_fail(builder: Builder, e: Exception)
  add_builder_ok(builder: Builder)
  add_copy_missing(filename: str, object_name: str)
  add_copy_sha1(filename: str, object_name: str)
  add_nop(filename: str, object_name: str)
  get_builder_fail()
  get_builder_ok()
  get_copy_missing()
  get_nop()
  get_os_error_code() → int

class pydmt.core.pydmt.PyDMT

  Bases: `object`

  add_builder(b: Builder) → None
  build_all() → BuildProcessStats

    Build all the targets, very high level method TODO: order builders by depenencies and do this multi-core :return: statistics about the build

  build_by_builder(builder: Builder, stats: BuildProcessStats)

    run one builder, return statistics about the run

  build_by_target(target: str, stats: BuildProcessStats) → None
  build_by_targets(targets: list[str], stats: BuildProcessStats) → None
  clean_all() → None

    Clean all targets

## pydmt.core.tempdir module

tempdir.py

pydmt.core.tempdir.cd(new_dir: str, cleanup: Callable)

pydmt.core.tempdir.tempdir()

## Module contents

__init__.py